@@ -1,3 +1,5 @@
+# -*- coding: future_fstrings -*-
+from __future__ import print_function
 # Standard library imports
 import logging
 import argparse
