@@ -1,3 +1,5 @@
+# -*- coding: future_fstrings -*-
+from __future__ import print_function
 # Standard library imports
 from copy import error
 import os
